==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/BubbleSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SizeScaleDescriptionMetadata } from "./SizeScaleDescriptionMetadata";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { BubbleSeriesDescription } from "./BubbleSeriesDescription";
/**
 * @hidden
 */
var BubbleSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BubbleSeriesDescriptionMetadata, _super);
    function BubbleSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BubbleSeriesDescriptionMetadata.b = function (a) {
        if (BubbleSeriesDescriptionMetadata.a == null) {
            BubbleSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BubbleSeriesDescriptionMetadata.c(BubbleSeriesDescriptionMetadata.a);
        }
        if (a.j(BubbleSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(BubbleSeriesDescriptionMetadata.a);
        SizeScaleDescriptionMetadata.d(a);
        BrushScaleDescriptionMetadata.d(a);
    };
    BubbleSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
        a.item("RadiusMemberPath", "String");
        a.item("RadiusScale", "ExportedType:SizeScale");
        a.item("LabelMemberPath", "String");
        a.item("FillMemberPath", "String");
        a.item("FillScale", "ExportedType:BrushScale");
        a.item("FillScaleUseGlobalValues", "Boolean");
        a.item("MarkerOutlineUsesFillScale", "Boolean");
        a.item("MarkerOutlineBrightness", "Number:double");
        a.item("MarkerBrushBrightness", "Number:double");
        a.item("RadiusScaleUseGlobalValues", "Boolean");
        a.item("RadiusMemberAsLegendLabel", "String");
        a.item("FillMemberAsLegendLabel", "String");
        a.item("RadiusMemberAsLegendUnit", "String");
        a.item("FillMemberAsLegendUnit", "String");
    };
    BubbleSeriesDescriptionMetadata.d = function (a) {
        BubbleSeriesDescriptionMetadata.b(a);
        a.aa("BubbleSeries", function () { return new BubbleSeriesDescription(); });
        a.z("BubbleSeries", BubbleSeriesDescriptionMetadata.a);
    };
    BubbleSeriesDescriptionMetadata.$t = markType(BubbleSeriesDescriptionMetadata, 'BubbleSeriesDescriptionMetadata');
    BubbleSeriesDescriptionMetadata.a = null;
    return BubbleSeriesDescriptionMetadata;
}(Base));
export { BubbleSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/BubbleSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SizeScaleDescriptionMetadata } from "./SizeScaleDescriptionMetadata";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { BubbleSeriesDescription } from "./BubbleSeriesDescription";
/**
 * @hidden
 */
var BubbleSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BubbleSeriesDescriptionMetadata, _super);
    function BubbleSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BubbleSeriesDescriptionMetadata.b = function (a) {
        if (BubbleSeriesDescriptionMetadata.a == null) {
            BubbleSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BubbleSeriesDescriptionMetadata.c(BubbleSeriesDescriptionMetadata.a);
        }
        if (a.k(BubbleSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(BubbleSeriesDescriptionMetadata.a);
        SizeScaleDescriptionMetadata.d(a);
        BrushScaleDescriptionMetadata.d(a);
    };
    BubbleSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
        a.item("RadiusMemberPath", "String");
        a.item("RadiusScale", "ExportedType:SizeScale");
        a.item("LabelMemberPath", "String");
        a.item("FillMemberPath", "String");
        a.item("FillScale", "ExportedType:BrushScale");
        a.item("FillScaleUseGlobalValues", "Boolean");
        a.item("MarkerOutlineUsesFillScale", "Boolean");
        a.item("MarkerOutlineBrightness", "Number:double");
        a.item("MarkerBrushBrightness", "Number:double");
        a.item("RadiusScaleUseGlobalValues", "Boolean");
        a.item("RadiusMemberAsLegendLabel", "String");
        a.item("FillMemberAsLegendLabel", "String");
        a.item("RadiusMemberAsLegendUnit", "String");
        a.item("FillMemberAsLegendUnit", "String");
    };
    BubbleSeriesDescriptionMetadata.d = function (a) {
        BubbleSeriesDescriptionMetadata.b(a);
        a.ac("BubbleSeries", function () { return new BubbleSeriesDescription(); });
        a.ab("BubbleSeries", BubbleSeriesDescriptionMetadata.a);
    };
    BubbleSeriesDescriptionMetadata.$t = markType(BubbleSeriesDescriptionMetadata, 'BubbleSeriesDescriptionMetadata');
    BubbleSeriesDescriptionMetadata.a = null;
    return BubbleSeriesDescriptionMetadata;
}(Base));
export { BubbleSeriesDescriptionMetadata };
